@@ -39,9 +39,12 @@ class ResourceInstance(Resource):
 
   def instantiate_subresources(self):
     """ Instantiate members for resources that live off this one. """
+    instantiated = []
     for subresource_class in self.subresources:
       subresource = subresource_class(self.owning_client, self.uri)
+      instantiated.append(subresource)
       setattr(self, subresource_class.collection_name, subresource)
+    return instantiated
 
   def populate_from_json(self, json_obj):
     """
